@@ -3,5 +3,5 @@ from .data import MNISTDataLoader, CIFAR10DataLoader
 from .Net import *
 from .test import Test
 from .train import Train
-from .plot import mis, graph, testvtrain, class_acc
+from .plot import mis, graph, testvtrain, class_acc, mis_grad
 from .data_summary import model_summary, display
\ No newline at end of file
